@@ -1,4 +1,4 @@
-# Copyrights 2007-2016 by [Mark Overmeer].
+# Copyrights 2007-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
@@ -8,7 +8,7 @@ use strict;
 
 package Log::Report::Extract::PerlPPI;
 use vars '$VERSION';
-$VERSION = '1.05';
+$VERSION = '1.07';
 
 use base 'Log::Report::Extract';
 
@@ -21,6 +21,7 @@ my %msgids =
  ( __   => [1,    0,    0,   0,   0]
  , __x  => [1,    0,    1,   1,   0]
  , __xn => [2,    1,    1,   1,   0]
+ , __nx => [2,    1,    1,   1,   0]
  , __n  => [2,    1,    1,   0,   0]
  , N__  => [1,    0,    1,   1,   0]  # may be used with opts/vars
  , N__n => [2,    0,    1,   1,   0]  # idem
@@ -68,8 +69,13 @@ sub process($@)
             next NODE;
         }
 
+		# Take domains which are as first parameter after 'use Log::Report'
         if($node->isa('PPI::Statement::Include'))
-        {   $node->type eq 'use' && $node->module eq 'Log::Report'
+        {   $node->type eq 'use'
+                or next NODE;
+
+   			my $module = $node->module;
+ 			$module eq 'Log::Report' || $module eq 'Dancer2::Plugin::LogReport'
                 or next NODE;
 
             $include++;
